@@ -65,6 +65,9 @@ module Network.WebSockets
     , ServerApp
     , runServer
     , runServerWith
+    , ServerOptions (..)
+    , defaultServerOptions
+    , runServerWithOptions
 
       -- * Utilities for writing your own server
     , makeListenSocket
@@ -80,6 +83,7 @@ module Network.WebSockets
     , newClientConnection
 
       -- * Utilities
+    , withPingThread
     , forkPingThread
     ) where
 
